@@ -12,17 +12,12 @@ impl fmt::Display for ProcessStatus {
 }
 
 #[doc = include_str!("../../md_doc/process.md")]
-#[derive(Clone)]
 pub struct Process {
     pid: Pid,
     parent: Option<Pid>,
 }
 
 impl ProcessExt for Process {
-    fn kill(&self) -> bool {
-        false
-    }
-
     fn kill_with(&self, _signal: Signal) -> Option<bool> {
         None
     }
